=====================================
``psyclone.tests.dynamo0p3_cma_test``
=====================================

.. automodule:: psyclone.tests.dynamo0p3_cma_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.dynamo0p3_cma_test
